;-- The .emacs file of David Dorward
;-- Designed for GNU emacs

;--Load files from Sams Teach Yourself Emacs in 21 days
    (setq load-path (cons "~/emacs/lisp" load-path))
    (require 'sams-lib)

;--No menus at command line
    (if (equal window-system nil)
    (menu-bar-mode nil))

;--Load VM email software
    (autoload 'vm "vm" "Start VM on your primary inbox." t)
    (autoload 'vm-other-frame "vm" "Like `vm' but starts in another frame." t)
    (autoload 'vm-visit-folder "vm" "Start VM on an arbitrary folder." t)
    (autoload 'vm-visit-virtual-folder "vm" "Visit a VM virtual folder." t)
    (autoload 'vm-mode "vm" "Run VM major mode on a buffer" t)
    (autoload 'vm-mail "vm" "Send a mail message using VM." t)
    (autoload 'vm-submit-bug-report "vm" "Send a bug report about VM." t)

;--Support for compressed files
    (require 'jka-compr)

;--Load Template support
    (require 'template)
    (template-initialize)

;--EMAIL
;--Make things go to @dorward.co.uk not @baydon.dorward.co.uk, use "name <email@where>", Who am I?)
(custom-set-variables '(mail-host-address "dorward.co.uk")
		      '(mail-from-style (quote angles))
		      '(user-mail-address "david@dorward.co.uk"))

;--Assign a prefix for each quoted line in email replies and forwards
    (setq mail-yank-prefix ">")

;--Save every outgoing message to a file
    (setq mail-archive-file-name "~/docs/email/sent-items")

;--Automatically append ~/.signature to end of all emails
(setq mail-signature t)

;--Use Windoze style selection, [del], [home], [end], 
(custom-set-variables '(pc-selection-mode t nil (pc-select)))

(custom-set-faces)

;-- MINIBUFFER & THINGS TO DISPLAY

;--Show the time in the minibuffer 
    (display-time) 

;--Turn on the column numbering in the minibuffer 
    (column-number-mode 1) 

;--Replace yes/no+enter prompts with y/n prompts
    (fset 'yes-or-no-p 'y-or-n-p) 

;--Disable the menu-bar in console mode for a little more screen space. You can still use F10 to access it in the minibuffer
    (menu-bar-mode (if window-system 1 -1)) 

;--Format the title-bar to always include the buffer name
     (setq frame-title-format "emacs - %b")

;-- HIGHLIGHTING

;--Highlight matching parenthesis (lifesaving when coding)
    (setq show-paren-mode t)
    (setq show-paren-style 'parenthesis)

;--Put as much syntax highlighting into documents as possible
    (setq font-lock-maximum-decoration t)

;--Enable syntax-highlighting
    (global-font-lock-mode 1 t)

;-- MISC

;--Provide access to system clipboard
     (setq x-select-enable-clipboard t)

;--Change default major mode to text from fundamental
     (setq default-major-mode 'text-mode)

;--Ddon't automatically add new lines when scrolling down at the bottom of a buffer
     (setq next-line-add-newlines nil)

;--Scroll just one line when hitting the bottom of the window
     (setq scroll-step 1)

;--Html-helper-mode
     (autoload 'html-helper-mode "html-helper-mode" "Yay HTML" t)

;--Word-wrap when editing an email message
     (add-hook 'mail-mode-hook 'turn-on-auto-fill)

;--Use html-helper-mode when editing .html files
     (setq auto-mode-alist (cons '("\\.htm$" . html-helper-mode) auto-mode-alist))
     (setq auto-mode-alist (cons '("\\.html$" . html-helper-mode) auto-mode-alist))

;--Allow me to use Lucida Typewriter font
      '(font-menu-ignore-scaled-fonts nil)

;--set From: address used in header of email I send
;      '(user-mail-address "david@dorward.co.uk")

;--Load bbdb
     (require 'bbdb)
     (bbdb-initialize)